@@ -35,14 +35,13 @@ static inline void
 yad_list_add_row (GtkTreeStore *m, GtkTreeIter *it, gchar *row_id, gchar *par_id)
 {
   GtkTreePath *row_path;
-  GtkTreeIter *parent = NULL;
+  GtkTreeIter pit, *parent = NULL;
 
   if (par_id && par_id[0])
     {
       GtkTreePath *par_path = g_hash_table_lookup (row_hash, par_id);
       if (par_path)
         {
-          GtkTreeIter pit;
           if (gtk_tree_model_get_iter (GTK_TREE_MODEL (m), &pit, par_path))
             parent = &pit;
         }
@@ -437,7 +436,7 @@ add_columns ()
             gtk_tree_view_column_add_attribute (column, renderer, "font", font_col);
           gtk_tree_view_column_set_sort_column_id (column, i);
           gtk_tree_view_column_set_resizable (column, TRUE);
-          
+
           if (col->type == YAD_COLUMN_TIP)
             options.list_data.tooltip_column = i + 1;
           break;
@@ -758,7 +757,7 @@ get_data_as_string (GtkTreeIter *iter)
 static void edit_row_cb (GtkMenuItem *item, gpointer data);
 
 static void
-double_click_cb (GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer data)
+double_click_cb (GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer d)
 {
   GtkTreeModel *model;
   GtkTreeIter iter;
@@ -1118,7 +1117,7 @@ row_sep_func (GtkTreeModel *m, GtkTreeIter *it, gpointer data)
     return FALSE;
 
   gtk_tree_model_get (m, it, options.list_data.sep_column - 1, &name, -1);
-  return (strcmp (name, options.list_data.sep_value) == 0);
+  return (name && strcmp (name, options.list_data.sep_value) == 0);
 }
 
 static inline void
