@@ -150,6 +150,13 @@ unfocus_cb (GtkWidget *w, GdkEventFocus *ev, gpointer d)
   return FALSE;
 }
 
+static gboolean
+link_cb (GtkLabel *l, gchar *uri, gpointer d)
+{
+  open_uri (uri);
+  return TRUE;
+}
+
 void
 yad_exit (gint id)
 {
@@ -195,19 +202,39 @@ create_layout (GtkWidget *dlg)
           gchar *buf = g_strcompress (options.data.dialog_text);
 
           text = gtk_label_new (NULL);
-          if (!options.data.no_markup)
-            gtk_label_set_markup (GTK_LABEL (text), buf);
-          else
-            gtk_label_set_text (GTK_LABEL (text), buf);
-          g_free (buf);
-
           gtk_widget_set_name (text, "yad-dialog-label");
           gtk_label_set_line_wrap (GTK_LABEL (text), TRUE);
           gtk_label_set_selectable (GTK_LABEL (text), options.data.selectable_labels);
-          gtk_label_set_justify (GTK_LABEL (text), options.data.text_align);
-          gtk_widget_set_state_flags (text, GTK_STATE_NORMAL, FALSE);
-          gtk_label_set_xalign (GTK_LABEL (text), options.data.text_align);
+          gtk_widget_set_state_flags (text, GTK_STATE_FLAG_NORMAL, FALSE);
           gtk_widget_set_can_focus (text, FALSE);
+
+          if (options.data.text_width > 0)
+            gtk_label_set_width_chars (GTK_LABEL (text), options.data.text_width);
+
+          /* set label align and justification */
+          switch (options.data.text_align)
+            {
+            case GTK_JUSTIFY_LEFT:
+            case GTK_JUSTIFY_FILL:
+              gtk_label_set_xalign (GTK_LABEL (text), 0.0);
+              break;
+            case GTK_JUSTIFY_RIGHT:
+              gtk_label_set_xalign (GTK_LABEL (text), 1.0);
+              break;
+            case GTK_JUSTIFY_CENTER:
+              gtk_label_set_xalign (GTK_LABEL (text), 0.5);
+              break;
+            }
+          gtk_label_set_justify (GTK_LABEL (text), options.data.text_align);
+
+          if (!options.data.no_markup)
+            {
+              gtk_label_set_markup (GTK_LABEL (text), buf);
+              g_signal_connect (G_OBJECT (text), "activate-link", G_CALLBACK (link_cb), NULL);
+            }
+          else
+            gtk_label_set_text (GTK_LABEL (text), buf);
+          g_free (buf);
         }
     }
 
@@ -270,16 +297,11 @@ create_layout (GtkWidget *dlg)
     }
 
   /* add expander */
-  imw = NULL;
   if (mw && options.data.expander)
     {
-      exp = gtk_expander_new_with_mnemonic (options.data.expander);
+      imw = exp = gtk_expander_new_with_mnemonic (options.data.expander);
       gtk_expander_set_expanded (GTK_EXPANDER (exp), FALSE);
-      if (mw)
-        {
-          gtk_container_add (GTK_CONTAINER (exp), mw);
-          imw = exp;
-        }
+      gtk_container_add (GTK_CONTAINER (exp), mw);
     }
   else
     imw = mw;
@@ -359,6 +381,8 @@ create_dialog (void)
       else
         gtk_window_set_icon_name (GTK_WINDOW (dlg), options.data.window_icon);
     }
+  else
+    gtk_window_set_icon_name (GTK_WINDOW (dlg), "yad");
 
   /* set window borders */
   if (options.data.borders < 0)
@@ -532,15 +556,6 @@ create_dialog (void)
   /* show widgets */
   gtk_widget_show_all (vbox);
 
-  if (options.data.width > 0)
-    gtk_widget_set_size_request (vbox, options.data.width, options.data.height);
-  else
-    {
-      gint mw, nw;
-      gtk_widget_get_preferred_width (vbox, &mw, &nw);
-      gtk_widget_set_size_request (vbox, nw, -1);
-    }
-
   /* parse geometry or move window, if given. must be after showing widget */
   if (!options.data.maximized && !options.data.fullscreen)
     {
@@ -570,7 +585,7 @@ create_dialog (void)
 
       if (xf)
         {
-          fprintf (xf, "0x%lX", GDK_WINDOW_XID (gtk_widget_get_window (dlg)));
+          fprintf (xf, "0x%lX\n", GDK_WINDOW_XID (gtk_widget_get_window (dlg)));
 
           if (options.xid_file)
             fclose (xf);
@@ -731,10 +746,26 @@ main (gint argc, gchar ** argv)
     is_x11 = TRUE;
 #endif
 
-  /* parse custom gtkrc */
-  if (options.gtkrc_file)
+  /* parse custom css */
+  if (options.css)
     {
       GtkCssProvider *css = gtk_css_provider_new ();
+
+      if (g_file_test (options.css, G_FILE_TEST_EXISTS))
+        gtk_css_provider_load_from_path (css, options.css, NULL);
+      else
+        gtk_css_provider_load_from_data (css, options.css, -1, NULL);
+      gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (css),
+                                                 GTK_STYLE_PROVIDER_PRIORITY_USER);
+      g_object_unref (css);
+    }
+  else if (options.gtkrc_file)
+    {
+      GtkCssProvider *css = gtk_css_provider_new ();
+
+      if (options.debug)
+        g_printerr (_("WARNING: Using gtkrc option is deprecated, please use --css instead\n"));
+
       gtk_css_provider_load_from_path (css, options.gtkrc_file, NULL);
       gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (css),
                                                  GTK_STYLE_PROVIDER_PRIORITY_USER);
@@ -865,7 +896,7 @@ main (gint argc, gchar ** argv)
       if (is_x11)
         {
           /* add YAD_XID variable */
-          str = g_strdup_printf ("0x%X", (guint) GDK_WINDOW_XID (gtk_widget_get_window (dialog)));
+          str = g_strdup_printf ("0x%lX", GDK_WINDOW_XID (gtk_widget_get_window (dialog)));
           g_setenv ("YAD_XID", str, TRUE);
         }
 
