@@ -198,7 +198,7 @@ update_preview (GtkFileChooser * chooser, GtkWidget *p)
                   gchar *smtime;
 
                   stat (file, &st);
-                  smtime = g_strdup_printf ("%d", st.st_mtime);
+                  smtime = g_strdup_printf ("%lu", st.st_mtime);
                   g_free (file);
 
                   /* save thumbnail */
@@ -714,6 +714,7 @@ pango_to_css (gchar *font)
         case PANGO_STYLE_ITALIC:
           g_string_append (str, "italic ");
           break;
+        default: ;
         }
     }
   if (mask & PANGO_FONT_MASK_VARIANT)
@@ -759,6 +760,7 @@ pango_to_css (gchar *font)
         case PANGO_WEIGHT_ULTRAHEAVY:
           g_string_append (str, "Ultraheavy ");
           break;
+        default: ;
         }
     }
 
