@@ -221,7 +221,8 @@ typedef struct {
   guint timeout;
   gchar *to_indicator;
   gchar *dialog_text;
-  gdouble text_align;
+  guint text_width;
+  GtkJustification text_align;
   gchar *dialog_image;
   gchar *icon_theme;
   gchar *expander;
@@ -524,6 +525,7 @@ typedef struct {
   YadSourceData source_data;
 #endif
 
+  gchar *css;
   gchar *gtkrc_file;
 
   GtkPolicyType hscroll_policy;
